@@ -1,10 +1,8 @@
-package MooseX::Meta::TypeCoercion::Structured::Optional;
+package ## Hide from PAUSE
+  MooseX::Meta::TypeCoercion::Structured::Optional;
 BEGIN {
   $MooseX::Meta::TypeCoercion::Structured::Optional::AUTHORITY = 'cpan:JJNAPIORK';
 }
-BEGIN {
-  $MooseX::Meta::TypeCoercion::Structured::Optional::VERSION = '0.25';
-}
 
 use Moose;
 extends 'Moose::Meta::TypeCoercion';
@@ -72,7 +70,7 @@ Robert Sedlacek <rs@474.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by John Napiorkowski.
+This software is copyright (c) 2011 by John Napiorkowski.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
